"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assertState_1 = __importDefault(require("./assertState"));
const Semaphore_1 = __importDefault(require("./Semaphore"));
class Batcher {
    fn;
    concurrency;
    maxBatchSize;
    q = Array();
    constructor(fn, 
    // By asking for a Semaphore instead of simply a concurrency number, this Batcher's concurrency can be shared with other things (in a naive first-come-first-served way).
    concurrency = new Semaphore_1.default(1), maxBatchSize) {
        this.fn = fn;
        this.concurrency = concurrency;
        this.maxBatchSize = maxBatchSize;
    }
    async execute(input) {
        return new Promise((resolve) => {
            this.q.push({ resolve, input });
            // We don't need to batch by timers (e.g. debounce), as if there is a lot of activity, it will be efficient because the subsequent batches will be optimally sized, and if there isn't, then it doesn't matter. OTOH, using a timer is far more complex and subtle.
            // Intentionally do not wait for Promise.
            void this.concurrency.add(async () => {
                // https://stackoverflow.com/a/48421425/6249022
                const dq = this.maxBatchSize
                    ? this.q.splice(0, this.maxBatchSize)
                    : this.q.splice(0);
                const outputs = await this.fn(dq.map((e) => e.input));
                (0, assertState_1.default)(outputs.length === dq.length);
                for (const [i, out] of outputs.entries()) {
                    dq[i].resolve(out);
                }
            });
        });
    }
}
exports.default = Batcher;
